@@ -68,8 +68,9 @@ class FaustAgent():
   metrics_server: Service
 
   def setup_metrics(self):
+    name = self.agent_id.replace(".", "_").replace('-', '_')
     self.metrics.inbound_counter = Counter(
-      f'delphai_{self.agent_id.replace(".", "_")}_inbound_counter',
+      f'delphai_{name}_inbound_counter',
       'incoming requests',
       const_labels={
         'step': self.step,
@@ -77,7 +78,7 @@ class FaustAgent():
       },
     )
     self.metrics.processed_counter = Counter(
-      f'delphai_{self.agent_id.replace(".", "_")}_processed_counter',
+      f'delphai_{name}_processed_counter',
       'processed requests',
       const_labels={
         'step': self.step,
@@ -85,7 +86,7 @@ class FaustAgent():
       },
     )
     self.metrics.lag_timer = Counter(
-      f'delphai_{self.agent_id.replace(".", "_")}_lag_timer',
+      f'delphai_{name}_lag_timer',
       'time to process requests',
       const_labels={
         'step': self.step,
